@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.site.deploy;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,6 +16,7 @@ package org.apache.maven.plugins.site.deploy;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.site.deploy;
 
 import org.apache.maven.model.Site;
 import org.apache.maven.plugin.MojoExecutionException;
@@ -37,13 +36,10 @@ import org.apache.maven.plugins.annotations.Mojo;
  *
  * @since 2.0
  */
-@Mojo( name = "deploy" )
-public class SiteDeployMojo
-    extends AbstractDeployMojo
-{
+@Mojo(name = "deploy")
+public class SiteDeployMojo extends AbstractDeployMojo {
     @Override
-    protected boolean isDeploy()
-    {
+    protected boolean isDeploy() {
         return true;
     }
 
@@ -51,9 +47,7 @@ public class SiteDeployMojo
      * Deploy distribution site url is directly the current project value.
      */
     @Override
-    protected String determineTopDistributionManagementSiteUrl()
-        throws MojoExecutionException
-    {
+    protected String determineTopDistributionManagementSiteUrl() throws MojoExecutionException {
         return getDeploySite().getUrl();
     }
 
@@ -61,9 +55,7 @@ public class SiteDeployMojo
      * Deploy directly to the current project's distribution management site.
      */
     @Override
-    protected Site determineDeploySite()
-        throws MojoExecutionException
-    {
-        return getSite( getTopLevelProject( project ) );
+    protected Site determineDeploySite() throws MojoExecutionException {
+        return getSite(getTopLevelProject(project));
     }
 }
