@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.site.deploy;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,8 +16,10 @@ package org.apache.maven.plugins.site.deploy;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.site.deploy;
 
 import java.util.Map;
+
 import org.apache.maven.model.Build;
 import org.apache.maven.model.Plugin;
 import org.apache.maven.model.PluginManagement;
@@ -29,7 +29,6 @@ import org.apache.maven.plugins.annotations.Mojo;
 import org.apache.maven.plugins.annotations.Parameter;
 import org.apache.maven.plugins.annotations.ResolutionScope;
 import org.apache.maven.project.MavenProject;
-import org.apache.maven.shared.utils.StringUtils;
 import org.codehaus.plexus.util.xml.Xpp3Dom;
 
 /**
@@ -41,10 +40,8 @@ import org.codehaus.plexus.util.xml.Xpp3Dom;
  *
  * @since 2.0
  */
-@Mojo( name = "stage-deploy", requiresDependencyResolution = ResolutionScope.TEST )
-public class SiteStageDeployMojo
-    extends AbstractStagingMojo
-{
+@Mojo(name = "stage-deploy", requiresDependencyResolution = ResolutionScope.TEST)
+public class SiteStageDeployMojo extends AbstractStagingMojo {
     /**
      * The staged site will be deployed to this URL.
      * <p/>
@@ -62,27 +59,26 @@ public class SiteStageDeployMojo
      *
      * @since 2.3
      */
-    @Parameter( property = "stagingSiteURL" )
+    @Parameter(property = "stagingSiteURL")
     private String stagingSiteURL;
 
     /**
-     * The identifier of the repository where the staging site will be deployed. This id will be used to lookup a
+     * The identifier of the site where the staged site will be deployed. This id will be used to lookup a
      * corresponding <code>&lt;server&gt;</code> entry from the <code>settings.xml</code>. If a matching
      * <code>&lt;server&gt;</code> entry is found, its configured credentials will be used for authentication.
      * <p/>
      * If this is not specified, then the corresponding value of <code>distributionManagement.site.id</code>
      * will be taken as default, unless this is not defined either then the String
-     * <code>"stagingSite"</code> is used. (<strong>Note</strong>:
-     * until v. 2.3 and 3.0-beta-3 the String <code>"stagingSite"</code> is always used.)
+     * <code>"stagingSite"</code> is used. Note that the alias {@code stagingRepositoryId} is deprecated
+     * for removal.
      *
      * @since 2.0.1
      */
-    @Parameter( property = "stagingRepositoryId" )
-    private String stagingRepositoryId;
+    @Parameter(property = "stagingSiteId", alias = "stagingRepositoryId")
+    private String stagingSiteId;
 
     @Override
-    protected boolean isDeploy()
-    {
+    protected boolean isDeploy() {
         return true;
     }
 
@@ -91,22 +87,18 @@ public class SiteStageDeployMojo
      * will be used.
      */
     @Override
-    protected String determineTopDistributionManagementSiteUrl()
-        throws MojoExecutionException
-    {
-        if ( StringUtils.isNotEmpty( topSiteURL ) )
-        {
-            getLog().debug( "stage-deploy top distributionManagement.site.url configured with topSiteURL parameter: "
-                + topSiteURL );
+    protected String determineTopDistributionManagementSiteUrl() throws MojoExecutionException {
+        if (topSiteURL != null && !topSiteURL.isEmpty()) {
+            getLog().debug("stage-deploy top distributionManagement.site.url configured with topSiteURL parameter: "
+                    + topSiteURL);
             return topSiteURL;
         }
 
-        if ( StringUtils.isNotEmpty( stagingSiteURL ) )
-        {
+        if (stagingSiteURL != null && !stagingSiteURL.isEmpty()) {
             // We need to calculate the first project that supplied same stagingSiteURL
             MavenProject topProject = getTopMostParentWithSameStagingSiteURL();
-            String url = getSite( topProject ).getUrl();
-            getLog().debug( "stage-deploy top stagingSiteURL found in " + topProject.getId() + " with value: " + url );
+            String url = getSite(topProject).getUrl();
+            getLog().debug("stage-deploy top stagingSiteURL found in " + topProject.getId() + " with value: " + url);
             return url;
         }
 
@@ -114,18 +106,16 @@ public class SiteStageDeployMojo
     }
 
     @Override
-    protected Site determineDeploySite()
-        throws MojoExecutionException
-    {
+    protected Site determineDeploySite() throws MojoExecutionException {
         Site top = new Site();
 
-        top.setId( stagingRepoId() );
-        getLog().info( "Using this server ID for stage deploy: " + top.getId() );
+        top.setId(determineStagingSiteId());
+        getLog().info("Using this server ID for stage deploy: " + top.getId());
 
         String stagingURL = determineStageDeploySiteURL();
-        getLog().info( "Using this base URL for stage deploy: " + stagingURL );
+        getLog().info("Using this base URL for stage deploy: " + stagingURL);
 
-        top.setUrl( stagingURL );
+        top.setUrl(stagingURL);
 
         return top;
     }
@@ -141,16 +131,13 @@ public class SiteStageDeployMojo
      *
      * @return the site for the top most project that has a stagingSiteURL. Not null.
      */
-    private MavenProject getTopMostParentWithSameStagingSiteURL()
-    {
+    private MavenProject getTopMostParentWithSameStagingSiteURL() {
         MavenProject current = project;
         MavenProject parent;
 
         // CHECKSTYLE_OFF: InnerAssignment
-        while (   // MSITE-585, MNG-1943
-                ( parent = siteTool.getParentProject( current, reactorProjects, localRepository ) ) != null
-                && stagingSiteURL.equals( getStagingSiteURL( parent ) ) )
-        {
+        while ( // MSITE-585, MNG-1943
+        (parent = current.getParent()) != null && stagingSiteURL.equals(getStagingSiteURL(parent))) {
             current = parent;
         }
         // CHECKSTYLE_ON: InnerAssignment
@@ -165,54 +152,44 @@ public class SiteStageDeployMojo
      * @param project The MavenProject, not null
      * @return The stagingSiteURL for the project, or null if it doesn't have one
      */
-    private String getStagingSiteURL( MavenProject project )
-    {
+    private String getStagingSiteURL(MavenProject project) {
         final String sitePluginKey = "org.apache.maven.plugins:maven-site-plugin";
 
-        if ( project == null )
-        {
+        if (project == null) {
             return null;
         }
 
         final Build build = project.getBuild();
-        if ( build == null )
-        {
+        if (build == null) {
             return null;
         }
 
         Map<String, Plugin> plugins = build.getPluginsAsMap();
 
-        Plugin sitePlugin = plugins.get( sitePluginKey );
-        if ( sitePlugin == null )
-        {
+        Plugin sitePlugin = plugins.get(sitePluginKey);
+        if (sitePlugin == null) {
             final PluginManagement buildPluginManagement = build.getPluginManagement();
-            if ( buildPluginManagement == null )
-            {
+            if (buildPluginManagement == null) {
                 return null;
             }
 
             plugins = buildPluginManagement.getPluginsAsMap();
-            sitePlugin = plugins.get( sitePluginKey );
+            sitePlugin = plugins.get(sitePluginKey);
         }
 
-        if ( sitePlugin == null )
-        {
+        if (sitePlugin == null) {
             return null;
         }
 
         final Xpp3Dom sitePluginConfiguration = (Xpp3Dom) sitePlugin.getConfiguration();
-        if ( sitePluginConfiguration == null )
-        {
+        if (sitePluginConfiguration == null) {
             return null;
         }
 
-        final Xpp3Dom child = sitePluginConfiguration.getChild( "stagingSiteURL" );
-        if ( child == null )
-        {
+        final Xpp3Dom child = sitePluginConfiguration.getChild("stagingSiteURL");
+        if (child == null) {
             return null;
-        }
-        else
-        {
+        } else {
             return child.getValue();
         }
     }
@@ -222,36 +199,28 @@ public class SiteStageDeployMojo
      *
      * @return the site URL for staging
      */
-    private String determineStageDeploySiteURL()
-        throws MojoExecutionException
-    {
-        if ( stagingSiteURL != null )
-        {
+    private String determineStageDeploySiteURL() throws MojoExecutionException {
+        if (stagingSiteURL != null) {
             // the user has specified a stagingSiteURL - use it
-            getLog().debug( "stagingSiteURL specified by the user: " + stagingSiteURL );
+            getLog().debug("stagingSiteURL specified by the user: " + stagingSiteURL);
             return stagingSiteURL;
         }
 
         // The user didn't specify a URL, use the top level site distribution URL and add "[/]staging/" to it
-        String defaultStagingSiteURL = appendSlash( getTopDistributionManagementSiteUrl() ) + DEFAULT_STAGING_DIRECTORY;
-        getLog().debug( "stagingSiteURL NOT specified, using the top level project: " + defaultStagingSiteURL );
+        String defaultStagingSiteURL = appendSlash(getTopDistributionManagementSiteUrl()) + DEFAULT_STAGING_DIRECTORY;
+        getLog().debug("stagingSiteURL NOT specified, using the top level project: " + defaultStagingSiteURL);
 
         return defaultStagingSiteURL;
     }
 
-    private String stagingRepoId()
-    {
-        if ( stagingRepositoryId != null )
-        {
-            return stagingRepositoryId;
+    private String determineStagingSiteId() {
+        if (stagingSiteId != null) {
+            return stagingSiteId;
         }
 
-        try
-        {
-            return getSite( project ).getId();
-        }
-        catch ( MojoExecutionException ex )
-        {
+        try {
+            return getSite(project).getId();
+        } catch (MojoExecutionException ex) {
             return "stagingSite";
         }
     }
