@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.site.stubs;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,83 +16,71 @@ package org.apache.maven.plugins.site.stubs;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.site.stubs;
 
 import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.io.InputStream;
 import java.util.Properties;
 
 import org.apache.maven.model.DistributionManagement;
 import org.apache.maven.model.Site;
 import org.apache.maven.model.io.xpp3.MavenXpp3Reader;
 import org.apache.maven.plugin.testing.stubs.MavenProjectStub;
-import org.codehaus.plexus.util.IOUtil;
-import org.codehaus.plexus.util.ReaderFactory;
-import org.codehaus.plexus.util.xml.XmlStreamReader;
+import org.codehaus.plexus.util.xml.pull.XmlPullParserException;
 
 /**
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
  *
  */
-public class SiteMavenProjectStub
-    extends MavenProjectStub
-{
+public class SiteMavenProjectStub extends MavenProjectStub {
     private File basedir;
 
     DistributionManagement distributionManagement = new DistributionManagement();
-    
-    public SiteMavenProjectStub( String projectName )
-    {
-        basedir = new File( super.getBasedir() + "/src/test/resources/unit/" + projectName );
 
-        XmlStreamReader reader = null;
-        try
-        {
-            reader = ReaderFactory.newXmlReader( new File( getBasedir(), "pom.xml" ) );
-            setModel( new MavenXpp3Reader().read( reader ) );
-            reader.close();
+    public SiteMavenProjectStub(String projectName) {
+        basedir = new File(super.getBasedir() + "/src/test/resources/unit/" + projectName);
+
+        File pom = new File(getBasedir(), "pom.xml");
+        try (InputStream in = new FileInputStream(pom)) {
+            setModel(new MavenXpp3Reader().read(in));
+            Site site = new Site();
+            site.setId("localhost");
+            distributionManagement.setSite(site);
+        } catch (IOException | XmlPullParserException e) {
+            throw new RuntimeException(e);
         }
-        catch ( Exception e )
-        {
-            throw new RuntimeException( e );
-        }
-        finally
-        {
-            IOUtil.close( reader);
-        }
-        Site site = new Site();
-        site.setId( "localhost" );
-        distributionManagement.setSite( site );
     }
 
     /**
      * @see org.apache.maven.project.MavenProject#getName()
      */
-    public String getName()
-    {
+    @Override
+    public String getName() {
         return getModel().getName();
     }
 
     /**
      * @see org.apache.maven.project.MavenProject#getProperties()
      */
-    public Properties getProperties()
-    {
+    @Override
+    public Properties getProperties() {
         return new Properties();
     }
 
     @Override
-    public DistributionManagement getDistributionManagement()
-    {
+    public DistributionManagement getDistributionManagement() {
         return distributionManagement;
     }
 
     /** {@inheritDoc} */
-    public File getBasedir()
-    {
+    @Override
+    public File getBasedir() {
         return basedir;
     }
 
-    public void setBasedir( File basedir )
-    {
+    public void setBasedir(File basedir) {
         this.basedir = basedir;
     }
 }
